@@ -16,19 +16,18 @@ use crate::messaging::{
 };
 use crate::peer::Peer;
 use crate::prefix_map::NetworkPrefixMap;
-use crate::types::utils::write_data_to_disk;
 use crate::types::PublicKey;
 use backoff::{backoff::Backoff, ExponentialBackoff};
 use bytes::Bytes;
+use dashmap::DashMap;
 use futures::future::join_all;
 use itertools::Itertools;
 use qp2p::{Config as QuicP2pConfig, Endpoint};
 use rand::rngs::OsRng;
 use rand::seq::SliceRandom;
-use serde::Serialize;
-use std::path::{Path, PathBuf};
+use std::path::PathBuf;
 use std::time::Duration;
-use std::{collections::HashMap, net::SocketAddr, sync::Arc};
+use std::{net::SocketAddr, sync::Arc};
 use tokio::{
     sync::mpsc::{channel, Sender},
     sync::RwLock,
@@ -43,9 +42,6 @@ pub(crate) const NUM_OF_ELDERS_SUBSET_FOR_QUERIES: usize = 3;
 // Number of bootstrap nodes to attempt to contact per batch (if provided by the node_config)
 pub(crate) const NODES_TO_CONTACT_PER_STARTUP_BATCH: usize = 3;
 
-// Root directory for Clients
-pub(crate) const SAFE_CLIENT_DIR: &str = ".safe/client";
-
 impl Session {
     /// Acquire a session by bootstrapping to a section, maintaining connections to several nodes.
     #[instrument(skip(err_sender), level = "debug")]
@@ -62,14 +58,8 @@ impl Session {
 
         let endpoint = Endpoint::new_client(local_addr, qp2p_config)?;
 
-        // Create client's root dir
-        let root_dir = create_client_root_dir(client_pk).await?;
-
-        // Write our PrefixMap to disk in our root dir
-        write_data_to_path(&prefix_map, &root_dir.join("prefix_map")).await?;
-
         let session = Session {
-            pending_queries: Arc::new(RwLock::new(HashMap::default())),
+            pending_queries: Arc::new(DashMap::default()),
             incoming_err_sender: Arc::new(err_sender),
             endpoint,
             network: Arc::new(prefix_map),
@@ -78,7 +68,6 @@ impl Session {
             genesis_key,
             initial_connection_check_msg_id: Arc::new(RwLock::new(None)),
             standard_wait,
-            root_dir,
         };
 
         Ok(session)
@@ -159,7 +148,6 @@ impl Session {
         payload: Bytes,
     ) -> Result<QueryResult, Error> {
         let endpoint = self.endpoint.clone();
-        let pending_queries = self.pending_queries.clone();
 
         let chunk_addr = if let DataQuery::GetChunk(address) = query {
             Some(address)
@@ -205,18 +193,19 @@ impl Session {
 
         let (sender, mut receiver) = channel::<QueryResponse>(7);
 
-        let pending_queries_for_thread = pending_queries.clone();
         if let Ok(op_id) = query.operation_id() {
-            let _handle = tokio::spawn(async move {
-                // Insert the response sender
-                trace!("Inserting channel for op_id {:?}", op_id);
-                let _old = pending_queries_for_thread
-                    .write()
-                    .await
-                    .insert(op_id.clone(), sender);
+            // Insert the response sender
+            trace!("Inserting channel for op_id {:?}", (msg_id, op_id.clone()));
+            if let Some(mut entry) = self.pending_queries.get_mut(&op_id) {
+                let senders_vec = entry.value_mut();
+                senders_vec.push((msg_id, sender))
+            } else {
+                let _nonexistant_entry = self
+                    .pending_queries
+                    .insert(op_id.clone(), vec![(msg_id, sender)]);
+            }
 
-                trace!("Inserted channel for {:?}", op_id);
-            });
+            trace!("Inserted channel for {:?}", op_id);
         } else {
             warn!("No op_id found for query");
         }
@@ -301,11 +290,20 @@ impl Session {
 
         if let Some(query) = &response {
             if let Ok(query_op_id) = query.operation_id() {
-                let _handle = tokio::spawn(async move {
-                    // Remove the response sender
-                    trace!("Removing channel for {:?}", query_op_id);
-                    let _old_channel = pending_queries.clone().write().await.remove(&query_op_id);
-                });
+                // Remove the response sender
+                trace!("Removing channel for {:?}", (msg_id, &query_op_id));
+                // let _old_channel =
+                if let Some(mut entry) = self.pending_queries.get_mut(&query_op_id) {
+                    let listeners_for_op = entry.value_mut();
+                    if let Some(index) = listeners_for_op
+                        .iter()
+                        .position(|(id, _sender)| *id == msg_id)
+                    {
+                        let _old_listener = listeners_for_op.swap_remove(index);
+                    }
+                } else {
+                    warn!("No listeners found for our op_id: {:?}", query_op_id)
+                }
             }
         }
 
@@ -564,31 +562,20 @@ pub(super) async fn send_message(
 
     let successful_sends = *successes.read().await;
     if failures > successful_sends {
-        error!("More errors when sending a message than successess");
+        error!("More errors when sending a message than successes");
     }
     Ok(())
 }
 
 #[instrument(skip_all, level = "trace")]
-pub(crate) async fn write_data_to_path<T: Serialize>(data: &T, path: &Path) -> Result<(), Error> {
-    // Write our PrefixMap to root dir
-    if let Err(e) = write_data_to_disk(data, path).await {
-        error!("Error writing data for Client at dir {:?}: {:?}", path, e);
-    }
-
-    Ok(())
-}
-
-#[instrument(skip_all, level = "trace")]
-pub(crate) async fn create_client_root_dir(client_pk: PublicKey) -> Result<PathBuf, Error> {
+pub(crate) async fn create_safe_dir() -> Result<PathBuf, Error> {
     let mut root_dir = dirs_next::home_dir().ok_or(Error::CouldNotReadHomeDir)?;
-    root_dir.push(SAFE_CLIENT_DIR);
-    root_dir.push(format!("sn_client-{}", client_pk));
+    root_dir.push(".safe");
 
     // Create `.safe/client` dir if not present
     tokio::fs::create_dir_all(root_dir.clone())
         .await
-        .map_err(|_| Error::CouldNotCreateRootDir)?;
+        .map_err(|_| Error::CouldNotCreateSafeDir)?;
 
     Ok(root_dir)
 }
